==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>དཔང་དཔྱད་དུས་བརྒལ།</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>སྡུད་སྡེར་ཡིག་ཆ་གཞན་གྱིས་བཟུང་ཡོད་པས། བཤིག་འདོན་བྱེད་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>སྡུད་སྡེར་ཡིག་ཆ་གཞན་གྱིས་བཟུང་ཡོད་པས། ཕྱིར་དོན་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། བདེ་འཇགས་ངང་ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>བམ་པོ་%1 </translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>མི་ཤེས་པ།</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>སྒྲིག་ཆས་རྒྱུན་གཏན་ངང་སྤོ་འབུད་བྱས་མེད།</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>“བདེ་འཇགས་སྤོ་འབུད་”མནན་རྗེས། མུ་མཐུད་འབྲེལ་མཐུད་བྱེད་མཚམས་འཇོག་རྒྱུ།</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། བདེ་འཇགས་ངང་ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>སྒྲིག་ཆས་བཤིག་འདོན་བྱེད་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>སྡུད་སྡེར་ནི་སྤྱོད་མཁན་“%1”གྱིས་བཅུག་པས། ཁྱོད་ལ་བཤིག་འདོན་བྱེད་དབང་མེད།</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>བབ་མཚུངས་ཀྱི་འགེལ་ཆས་རྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ཁ་འབྱེད་པ།</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>ཚང་མ་ཕྱིར་འདོན་བྱེད་པ།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>སྒྲིག་ཆས་བདེ་འཇགས་ངང་སྤོ་འབུད་བྱས་སོང་།</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>ཀློག་མི་རུང་བ་དང་འབྲི་མི་རུང་བ།</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>ཁྱོད་ལ་ཡིག་ཁུག་འདི་ཀློག་དབང་མེད།</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ཆོག</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>མིག་སྔའི་སྒྲིག་ཆས་བཤར་འབེབས་བཞིན་ཡོད་པས། བཤེར་འབེབས་མཚམས་འཇོག་རྒྱུ་ཡིན་ནམ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>མཚམས་འཇོགས།</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.3.orig.tar.xz: dde-file-manager-5.8.3/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>དཔང་དཔྱད་དུས་བརྒལ།</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>སྡུད་སྡེར་ཡིག་ཆ་གཞན་གྱིས་བཟུང་ཡོད་པས། བཤིག་འདོན་བྱེད་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>སྡུད་སྡེར་ཡིག་ཆ་གཞན་གྱིས་བཟུང་ཡོད་པས། ཕྱིར་དོན་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>འོད་སྡེར་བྲེལ་བཞིན་འདུག་པས། བདེ་འཇགས་ངང་ཕྱིར་བཏོན་ཐབས་བྲལ། </translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>བམ་པོ་%1 </translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>མི་ཤེས་པ།</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>སྒྲིག་ཆས་རྒྱུན་གཏན་ངང་སྤོ་འབུད་བྱས་མེད།</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>“བདེ་འཇགས་སྤོ་འབུད་”མནན་རྗེས། མུ་མཐུད་འབྲེལ་མཐུད་བྱེད་མཚམས་འཇོག་རྒྱུ།</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>སྒྲིག་ཆས་བཤིག་འདོན་བྱེད་ཐབས་བྲལ།</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>སྡུད་སྡེར་ནི་སྤྱོད་མཁན་“%1”གྱིས་བཅུག་པས། ཁྱོད་ལ་བཤིག་འདོན་བྱེད་དབང་མེད།</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>བབ་མཚུངས་ཀྱི་འགེལ་ཆས་རྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ཁ་འབྱེད་པ།</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>ཚང་མ་ཕྱིར་འདོན་བྱེད་པ།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>སྒྲིག་ཆས་བདེ་འཇགས་ངང་སྤོ་འབུད་བྱས་སོང་།</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>ཀློག་མི་རུང་བ་དང་འབྲི་མི་རུང་བ།</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>ཁྱོད་ལ་ཡིག་ཁུག་འདི་ཀློག་དབང་མེད།</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>མིག་སྔའི་སྒྲིག་ཆས་བཤར་འབེབས་བཞིན་ཡོད་པས། བཤེར་འབེབས་མཚམས་འཇོག་རྒྱུ་ཡིན་ནམ།</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>ཆོག</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>མཚམས་འཇོགས།</translation>
    </message>
</context>
</TS>
